import { createSlice, createAsyncThunk, PayloadAction } from "@reduxjs/toolkit";
import axios from "axios";

// Define TypeScript types
interface User {
	id: number;
	name: string;
	email: string;
	phone?: string;
	location?: string;
	managerAssigned?: string;
	vehicle?: string;
}

interface UserState {
	users: User[];
	loading: boolean;
	error: string | null;
}

// Initial state
const initialState: UserState = {
	users: [],
	loading: false,
	error: null,
};

// Async thunk to fetch user list
export const userList = createAsyncThunk<User[]>("users/fetchUsers", async () => {
	try {
		const response = await axios.get<User[]>("/api/users"); // Adjust the API endpoint as needed
		return response.data;
	} catch (error: any) {
		throw new Error(error.response?.data?.message || "Failed to fetch users");
	}
});

const userSlice = createSlice({
	name: "users",
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(userList.pending, (state) => {
				state.loading = true;
				state.error = null;
			})
			.addCase(userList.fulfilled, (state, action: PayloadAction<User[]>) => {
				state.loading = false;
				state.users = action.payload;
			})
			.addCase(userList.rejected, (state, action) => {
				state.loading = false;
				state.error = action.error.message || "Failed to fetch users";
			});
	},
});

export default userSlice.reducer;
